@@ -12,7 +12,7 @@ addCapitalDictCases("Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija:
 addCapitalDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo", "CPU apkrovos stebėtojui", "CPU apkrovos stebėtoją", "CPU apkrovos stebėtoju", "CPU apkrovos stebėtojuje");
 addDictCases("Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama");
 addDictCases("Dabartinės programos valdymas", "Dabartinės programos valdymo", "Dabartinės programos valdymui", "Dabartinės programos valdymą", "Dabartinės programos valdymu", "Dabartinės programos valdyme");
-addDictCases("Darbastalis", "Darbastalio", "Darbastaliui", "Darbastalį", "Darbastaliu", "Darbastalyje");
+addDictCases("Numatytas darbastalis", "Numatyto darbastalio", "Numatytam darbastaliui", "Numatytą darbastalį", "Numatyty darbastaliu", "Numatytame darbastalyje");
 addDictCases("Dvejetainis laikrodis", "Dvejetainio laikrodžio", "Dvejetainiam laikrodžiui", "Dvejetainį laikrodį", "Dvejetainiu laikrodžiu", "Dvejetainiame laikrodyje");
 addCapitalDictCases("Facebook", "Facebook", "Facebook", "Facebook", "Facebook", "Facebook");
 addDictCases("Failų stebėtojas", "Failų stebėtojo", "Failų stebėtojui", "Failų stebėtoją", "Failų stebėtoju", "Failų stebėtojuje");
@@ -28,10 +28,9 @@ addCapitalDictCases("Kate sesijų programėlė", "Kate sesijų programėlės", "
 addCapitalDictCases("KDE observatorija", "KDE observatorijos", "KDE observatorijai", "KDE observatoriją", "KDE observatorija", "KDE observatorijoje");
 addCapitalDictCases("KGet skritulinės diagramos programėlė", "KGet skritulinės diagramos programėlės", "KGet skritulinės diagramos programėlei", "KGet skritulinės diagramos programėlę", "KGet skritulinės diagramos programėle", "KGet skritulinės diagramos programėlėje");
 addCapitalDictCases("KGet stulpelinės diagramos programėlė", "KGet stulpelinės diagramos programėlės", "KGet stulpelinės diagramos programėlei", "KGet stulpelinės diagramos programėlę", "KGet stulpelinės diagramos programėle", "KGet stulpelinės diagramos programėlėje");
-addDictCases("Kietųjų diskų būklė", "Kietųjų diskų būklės", "Kietųjų diskų būklei", "Kietųjų diskų būklę", "Kietųjų diskų būkle", "Kietųjų diskų būklėje");
 addDictCases("Klaviatūra", "Klaviatūros", "Klaviatūrai", "Klaviatūrą", "Klaviatūra", "Klaviatūroje");
 addDictCases("Klaviatūros išdėstymas", "Klaviatūros išdėstymo", "Klaviatūros išdėstymui", "Klaviatūros išdėstymą", "Klaviatūros išdėstymu", "Klaviatūros išdėstyme");
-addDictCases("Konqueror profiliai", "Konqueror profilių", "Konqueror profiliams", "Konqueror profilius", "Konqueror profiliais", "Konqueror profiliuose");
+addCapitalDictCases("Konqueror profiliai", "Konqueror profilių", "Konqueror profiliams", "Konqueror profilius", "Konqueror profiliais", "Konqueror profiliuose");
 addDictCases("Konsole profiliai", "Konsole profilių", "Konsole profiliams", "Konsole profilius", "Konsole profiliais", "Konsole profiliuose");
 addCapitalDictCases("KTorrent", "KTorrent", "KTorrent", "KTorrent", "KTorrent", "KTorrent");
 addDictCases("Laikmatis", "Laikmačio", "Laikmačiui", "Laikmatį", "Laikmačiu", "Laikmatyje");
@@ -92,5 +91,6 @@ addDictCases("Veiklų juosta", "Veiklų juostos", "Veiklų juostai", "Veiklų ju
 addDictCases("Vienetų konvertuoklis", "Vienetų konvertuoklio", "Vienetų konvertuokliui", "Vienetų konvertuoklį", "Vienetų konvertuokliu", "Vienetų konvertuoklyje");
 addDictCases("Ženkliukas", "Ženkliuko", "Ženkliukui", "Ženkliuką", "Ženkliuku", "Ženkliuke");
 addDictCases("Žiniatinklio naršyklė", "Žiniatinklio naršyklės", "Žiniatinklio naršyklei", "Žiniatinklio naršyklę", "Žiniatinklio naršykle", "Žiniatinklio naršyklėje");
+addDictCases("Žinių bazė", "Žinių bazės", "Žinių bazei", "Žinių bazę", "Žinių baze", "Žinių bazėje");
 addDictCases("Žymelės", "Žymelių", "Žymelėms", "Žymeles", "Žymelėmis", "Žymelėse");
 addDictCases("Žodynas", "Žodyno", "Žodynui", "Žodyną", "Žodynu", "Žodyne");
